fido

package module
v1.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 30, 2026 License: GPL-3.0, GPL-3.0 Imports: 8 Imported by: 0

README

fido

Simple functional component system for htmx projects in Go that uses builder pattern

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Case

func Case[T comparable](match T, element Element) any

func Default

func Default(element Element) any

func EscapeString

func EscapeString(s string) string

Escapes a string to ensure it is safe HTML. Doesnt remove apostrophe

Types

type DefaultElement

type DefaultElement struct {
	// contains filtered or unexported fields
}

func NewDefaultElement

func NewDefaultElement(tag string) DefaultElement

Returns a new DefaultElement with the given tag.

func (*DefaultElement) Action

func (e *DefaultElement) Action(action string) Element

Sets the action attribute of the element to the given string.

func (*DefaultElement) Add

func (e *DefaultElement) Add(elements ...Element) Element

Appends the elements as children.

func (*DefaultElement) AddChild

func (e *DefaultElement) AddChild(child Element) Element

Appends the element as a child.

func (*DefaultElement) Alt

func (e *DefaultElement) Alt(alt string) Element

Sets the alt attribute of the element.

func (*DefaultElement) AtClick

func (e *DefaultElement) AtClick(handler string) Element

Sets @click attribute for alpine.js

func (*DefaultElement) Attr

func (e *DefaultElement) Attr(key string, value ...string) Element

Sets the given attribute key to the given value.

func (*DefaultElement) ChildWithId

func (e *DefaultElement) ChildWithId(id string) (Element, bool)

Returns the first child element with the given id recursively.

func (*DefaultElement) Children

func (e *DefaultElement) Children(elements ...Element) Element

Sets the children of the element.

func (*DefaultElement) Class

func (e *DefaultElement) Class(classes ...string) Element

Adds the given class or classes to the element.

func (*DefaultElement) Defer

func (e *DefaultElement) Defer(value ...bool) Element

Sets the defer attribute of the element.

func (*DefaultElement) For

func (e *DefaultElement) For(value string) Element

Sets the for attribute of the element.

func (*DefaultElement) GetAttr

func (e *DefaultElement) GetAttr(key string) string

Returns the value of the given attribute key.

func (*DefaultElement) GetAttrs

func (e *DefaultElement) GetAttrs() map[string]string

Returns a map of the attributes on the element.

func (*DefaultElement) GetChild

func (e *DefaultElement) GetChild(idx int) (Element, bool)

Returns the child element at the given index.

func (*DefaultElement) GetChildren

func (e *DefaultElement) GetChildren() []Element

Returns the children of the element.

func (*DefaultElement) GetChildrenWithClass

func (e *DefaultElement) GetChildrenWithClass(class string) []Element

Returns all descendants with the given class.

func (*DefaultElement) GetClasses

func (e *DefaultElement) GetClasses() []string

Returns an array of all the classes of the element.

func (*DefaultElement) GetContent

func (e *DefaultElement) GetContent() string

Returns the rendered children and text.

func (*DefaultElement) GetFirstChildWithClass

func (e *DefaultElement) GetFirstChildWithClass(class string) (Element, bool)

Returns the first descendant with the given class.

func (*DefaultElement) GetId

func (e *DefaultElement) GetId() string

Returns the id of the element.

func (*DefaultElement) GetNthChildWithClass

func (e *DefaultElement) GetNthChildWithClass(class string, n int) (Element, bool)

Returns the nth descendant with the given class.

func (*DefaultElement) GetStyle

func (e *DefaultElement) GetStyle(key string) string

Returns the value of the given style key.

func (*DefaultElement) GetStyles

func (e *DefaultElement) GetStyles() map[string]string

Returns a map of the styles on the element.

func (*DefaultElement) GetTag

func (e *DefaultElement) GetTag() string

Returns the HTML tag name of the element.

func (*DefaultElement) HXBoost

func (e *DefaultElement) HXBoost(boost ...bool) Element

Sets the hx-boost attribute of the element.

func (*DefaultElement) HXConfirm

func (e *DefaultElement) HXConfirm(prompt string) Element

Sets the hx-confirm attribute of the element.

func (*DefaultElement) HXDelete

func (e *DefaultElement) HXDelete(url string) Element

Sets the hx-delete attribute of the element.

func (*DefaultElement) HXGet

func (e *DefaultElement) HXGet(url string) Element

Sets the hx-get attribute of the element.

func (*DefaultElement) HXHistory

func (e *DefaultElement) HXHistory(history string) Element

Sets the hx-replace-url attribute of the element.

func (*DefaultElement) HXInclude added in v1.0.5

func (e *DefaultElement) HXInclude(selector string) Element

Sets the hx-include attribute of the element.

func (*DefaultElement) HXIndicator

func (e *DefaultElement) HXIndicator(indicator string) Element

Sets the hx-indicator attribute of the element.

func (*DefaultElement) HXOn

func (e *DefaultElement) HXOn(event string, script string) Element

Sets hx-on attribute for htmx

func (*DefaultElement) HXOob

func (e *DefaultElement) HXOob(oob string) Element

Sets the hx-oob attribute of the element.

func (*DefaultElement) HXPatch

func (e *DefaultElement) HXPatch(url string) Element

Sets the hx-patch attribute of the element.

func (*DefaultElement) HXPost

func (e *DefaultElement) HXPost(url string) Element

Sets the hx-post attribute of the element.

func (*DefaultElement) HXPushUrl

func (e *DefaultElement) HXPushUrl(pushUrl string) Element

Sets the hx-push-url attribute of the element.

func (*DefaultElement) HXPut

func (e *DefaultElement) HXPut(url string) Element

Sets the hx-put attribute of the element.

func (*DefaultElement) HXReplaceUrl

func (e *DefaultElement) HXReplaceUrl(replaceUrl string) Element

Sets the hx-replace-url attribute of the element.

func (*DefaultElement) HXSelect

func (e *DefaultElement) HXSelect(value string) Element

Sets the hx-select attribute of the element.

func (*DefaultElement) HXSwap

func (e *DefaultElement) HXSwap(value string) Element

Sets the hx-swap attribute of the element.

func (*DefaultElement) HXSwapOob

func (e *DefaultElement) HXSwapOob(oob string) Element

Sets the hx-swap-oob attribute of the element.

func (*DefaultElement) HXTarget

func (e *DefaultElement) HXTarget(target string) Element

Sets the hx-target attribute of the element.

func (*DefaultElement) HXTrigger

func (e *DefaultElement) HXTrigger(trigger string) Element

Sets the hx-trigger attribute of the element.

func (*DefaultElement) HXVals

func (e *DefaultElement) HXVals(json string) Element

Sets the hx-vals attribute of the element.

func (*DefaultElement) HasClass

func (e *DefaultElement) HasClass(class string) bool

Returns true if the element has the given class.

func (*DefaultElement) Href

func (e *DefaultElement) Href(href string) Element

Sets the href attribute of the element.

func (*DefaultElement) Id

func (e *DefaultElement) Id(value string) Element

Sets the id attribute of the element.

func (*DefaultElement) Method

func (e *DefaultElement) Method(method string) Element

Sets the method attribute of the element to the given string.

func (*DefaultElement) Name

func (e *DefaultElement) Name(name string) Element

Sets the name attribute of the element.

func (*DefaultElement) OnClick

func (e *DefaultElement) OnClick(value string) Element

Sets the onclick attribute of the element.

func (*DefaultElement) OobOnly

func (e *DefaultElement) OobOnly(w http.ResponseWriter)

Sends the element to the http.ResponseWriter as text/html.

func (*DefaultElement) Placeholder

func (e *DefaultElement) Placeholder(placeholder string) Element

Sets the placeholder attribute of the element.

func (*DefaultElement) Prepend

func (e *DefaultElement) Prepend(elements ...Element) Element

Prepends the elements as children.

func (*DefaultElement) PrependChild

func (e *DefaultElement) PrependChild(child Element) Element

Prepends the element as a child.

func (*DefaultElement) RemoveAttr

func (e *DefaultElement) RemoveAttr(keys ...string) Element

Removes the given attribute key from the element.

func (*DefaultElement) RemoveClass

func (e *DefaultElement) RemoveClass(classes ...string) Element

Removes the given class or classes from the element.

func (*DefaultElement) RemoveStyle

func (e *DefaultElement) RemoveStyle(styles ...string) Element

Removes the given style key from the element.

func (*DefaultElement) Render

func (e *DefaultElement) Render() string

Renders the element as HTML string.

func (*DefaultElement) RenderWithContent

func (e *DefaultElement) RenderWithContent(text string, children ...Element) string

Renders the element with the children first and text at the end.

func (*DefaultElement) Send

func (e *DefaultElement) Send(w http.ResponseWriter)

Sends the element to the http.ResponseWriter as text/html.

func (*DefaultElement) Src

func (e *DefaultElement) Src(src string) Element

Sets the src attribute of the element.

func (*DefaultElement) Style

func (e *DefaultElement) Style(style string) Element

Sets the given style key to the given value.

func (*DefaultElement) Submit

func (e *DefaultElement) Submit() Element

Sets the type attribute to "submit".

func (*DefaultElement) Tag

func (e *DefaultElement) Tag(tag string) Element

Sets the HTML tag name of the element.

func (*DefaultElement) Text

func (e *DefaultElement) Text(content string) Element

Sets the text content of the element.

func (*DefaultElement) Title

func (e *DefaultElement) Title(title string) Element

Sets the title attribute of the element.

func (*DefaultElement) Type

func (e *DefaultElement) Type(tipe string) Element

Sets the type attribute of the element.

func (*DefaultElement) UnsafeHtml

func (e *DefaultElement) UnsafeHtml(content string) Element

Sets the text content of the element without escaping.

func (*DefaultElement) Value

func (e *DefaultElement) Value(value string) Element

Sets the value attribute of the element.

func (*DefaultElement) XBind

func (e *DefaultElement) XBind(attr string, value string) Element

Sets x-bind attribute for alpine.js

func (*DefaultElement) XCloak

func (e *DefaultElement) XCloak() Element

Sets x-cloak attribute for alpine.js

func (*DefaultElement) XData

func (e *DefaultElement) XData(data string) Element

Sets x-data attribute for alpine.js

func (*DefaultElement) XHtml

func (e *DefaultElement) XHtml(value string) Element

Sets x-html attribute for alpine.js

func (*DefaultElement) XInit

func (e *DefaultElement) XInit(value string) Element

Sets x-init attribute for alpine.js

func (*DefaultElement) XModel

func (e *DefaultElement) XModel(value string) Element

Sets x-model attribute for alpine.js

func (*DefaultElement) XOn

func (e *DefaultElement) XOn(event string, value string) Element

Sets x-on attribute for alpine.js

func (*DefaultElement) XRef

func (e *DefaultElement) XRef(value string) Element

Sets x-ref attribute for alpine.js

func (*DefaultElement) XShow

func (e *DefaultElement) XShow(condition string) Element

Sets x-show attribute for alpine.js

func (*DefaultElement) XText

func (e *DefaultElement) XText(value string) Element

Sets x-text attribute for alpine.js

type Element

type Element interface {
	// Returns the HTML tag name of the element.
	GetTag() string
	// Sets the HTML tag name of the element.
	Tag(tag string) Element
	// Sets the defer attribute of the element.
	Defer(value ...bool) Element
	// Returns the id of the element.
	GetId() string
	// Returns the first child element with the given id recursively.
	ChildWithId(id string) (Element, bool)

	// Returns an array of all the classes of the element.
	GetClasses() []string
	// Returns true if the element has the given class.
	HasClass(class string) bool
	// Adds the given class or classes to the element.
	Class(classes ...string) Element
	// Removes the given class or classes from the element.
	RemoveClass(class ...string) Element
	// Returns a map of the styles on the element.
	GetStyles() map[string]string
	// Returns the value of the given style key.
	GetStyle(key string) string
	// Sets the given style key to the given value.
	Style(style string) Element
	// Removes the given style key from the element.
	RemoveStyle(key ...string) Element

	// Returns a map of the attributes on the element.
	GetAttrs() map[string]string
	// Returns the value of the given attribute key.
	GetAttr(key string) string
	// Sets the given attribute key to the given value.
	Attr(key string, value ...string) Element
	// Removes the given attribute key from the element.
	RemoveAttr(key ...string) Element
	// Returns the children of the element.
	GetChildren() []Element
	// Returns the child element at the given index.
	GetChild(idx int) (Element, bool)
	// Appends the element as a child.
	AddChild(child Element) Element
	// Appends the elements as children.
	Add(children ...Element) Element
	// Prepends elements as children.
	Prepend(children ...Element) Element
	// Prepends the element as a child.
	PrependChild(child Element) Element
	// Sets the children of the element.
	Children(children ...Element) Element
	// Returns all descendants with the given class.
	GetChildrenWithClass(class string) []Element
	// Returns the first descendant with the given class.
	GetFirstChildWithClass(class string) (Element, bool)
	// Returns the nth descendant with the given class.
	GetNthChildWithClass(class string, n int) (Element, bool)
	// Returns the rendered children and text.
	GetContent() string
	// Renders the element as HTML string.
	Render() string

	//// Common attrs
	// Sets the text content of the element.
	Text(content string) Element
	// Sets the HTML content of the element without escaping.
	UnsafeHtml(content string) Element
	// Sets the hx-post attribute of the element.
	HXPost(url string) Element
	// Sets the hx-get attribute of the element.
	HXGet(url string) Element
	// Sets the hx-put attribute of the element.
	HXPut(url string) Element
	// Sets the hx-patch attribute of the element.
	HXPatch(url string) Element
	// Sets the hx-delete attribute of the element.
	HXDelete(url string) Element
	// Sets the hx-confirm attribute of the element.
	HXConfirm(prompt string) Element
	// Sets the hx-target attribute of the element.
	HXTarget(target string) Element
	// Sets the hx-trigger attribute of the element.
	HXTrigger(trigger string) Element
	// Sets the hx-include attribute of the element.
	HXInclude(selector string) Element
	// Sets the hx-swap attribute of the element.
	HXSwap(value string) Element
	// Sets the hx-select attribute of the element.
	HXSelect(value string) Element
	// Sets the id attribute of the element.
	Id(value string) Element
	// Sets the name attribute of the element.
	Name(name string) Element
	// Sets the title attribute of the element.
	Title(title string) Element
	// Sets the for attribute of the element.
	For(name string) Element
	// Sets the type attribute of the element.
	Type(tipe string) Element
	// Sets the type attribute to "submit".
	Submit() Element
	// Sets the method attribute of the element to the given string.
	Method(method string) Element
	// Sets the action attribute of the element.
	Action(action string) Element
	// Sets the src attribute of the element.
	Src(src string) Element
	// Sets the value attribute of the element.
	Value(value string) Element
	// Sets the href attribute of the element.
	Href(href string) Element
	// Sets the placeholder attribute of the element.
	Placeholder(placeholder string) Element
	// Sets the alt attribute of the element.
	Alt(alt string) Element
	// Sets the onclick attribute of the element.
	OnClick(value string) Element
	// Sets the hx-indicator attribute of the element.
	HXIndicator(indicator string) Element
	// Sets the hx-oob attribute of the element.
	HXOob(oob string) Element
	// Sets the hx-swap-oob attribute of the element.
	HXSwapOob(oob string) Element
	// Sets the hx-vals attribute of the element.
	HXVals(json string) Element
	// Sets the hx-push-url attribute of the element.
	HXPushUrl(pushUrl string) Element
	// Sets the hx-replace-url attribute of the element.
	HXReplaceUrl(replaceUrl string) Element
	// Sets the hx-history attribute of the element.
	HXHistory(history string) Element
	// Sets hx-on attribute for htmx
	HXOn(event string, value string) Element
	// Sets the hx-boost attribute of the element.
	HXBoost(boost ...bool) Element
	// Sets x-data attribute for alpine.js
	XData(data string) Element
	// Sets @click attribute for alpine.js
	AtClick(handler string) Element
	// Sets x-bind attribute for alpine.js
	XBind(attr string, value string) Element
	// Sets x-on attribute for alpine.js
	XOn(event string, value string) Element
	// Sets x-text attribute for alpine.js
	XText(value string) Element
	// Sets x-html attribute for alpine.js
	XHtml(value string) Element
	// Sets x-model attribute for alpine.js
	XModel(value string) Element
	//  Sets x-show attribute for alpine.js
	XShow(condition string) Element
	// Sets x-init attribute for alpine.js
	XInit(value string) Element
	// Sets x-ref attribute for alpine.js
	XRef(value string) Element
	// Sets x-cloak attribute for alpine.js
	XCloak() Element

	Send(w http.ResponseWriter)

	OobOnly(w http.ResponseWriter)
}

func A

func A(href string, children ...Element) Element

Returns a new a element with the given href. If children are provided, they will be used as the content of the link.

func Body

func Body(children ...Element) Element

returns a body element If children are provided, they will be added as the content.

func Button

func Button(text string) Element

Returns a new button element with the given text.

func CheckboxGroup

func CheckboxGroup(name string, value string, options []Option) Element

func Div

func Div(class string, children ...Element) Element

Returns a new div element with the given class. If children are provided, they will be added as the content of the div.

func For

func For[T any](objs []T, element func(T, int) Element) Element

func Form

func Form(children ...Element) Element

Returns a new form element

func Fragment

func Fragment(children ...Element) Element

Returns a new element with no tag If children are provided, they will be added as the content of the element.

func FromHtml

func FromHtml(s string) (Element, error)

Parses an HTML string into a fido.Element

func H1

func H1(text string) Element

Returns a new h1 element with the given text

func H2

func H2(text string) Element

Returns a new h2 element with the given text

func H3

func H3(text string) Element

Returns a new h3 element with the given text

func H4

func H4(text string) Element

Returns a new h4 element with the given text

func H5

func H5(text string) Element

Returns a new h5 element with the given text

func H6

func H6(text string) Element

Returns a new h6 element with the given text

func Head(children ...Element) Element

returns a head element If children are provided, they will be added as the content.

func HiddenInput

func HiddenInput(name string, value string) Element

Returns a new hidden input element with the given name and value.

func Html

func Html(content string) Element

Returns a new html element with the given UNESCAPED content

func If

func If(condition bool, children ...Element) Element

func IfElse

func IfElse(condition bool, ifElement Element, elseElement ...Element) Element

func Img

func Img(src string) Element

Returns a new img element with the given src attribute.

func Input

func Input(name string) Element

Returns a new input element with the given name attribute.

func Label

func Label(text string) Element

Returns a new label element with the given text.

func Li

func Li(children ...Element) Element

returns a list item (li) tag If children are provided, they will be added as the content of the list item.

func List

func List[T any](data []T, rowFunc ...func(T, int) Element) Element

Returns a list of elements from the given data wrapped in a div using an optional function to render each item.

func NewElement

func NewElement(tag string) Element

Returns a new Element with the given tag.

func None

func None() Element

Returns a new element with no tag

func P

func P(text string) Element

Returns a new p element

func Picture

func Picture(alt string, sources ...PictureSource) Element

func RadioGroup

func RadioGroup(name string, value string, options []Option) Element

func Script

func Script(js string) Element

returns a script tag If js is provided, it will be used as the UNESCAPED content of the script tag.

func Section

func Section(children ...Element) Element

Returns a new section element If children are provided, they will be added as the content of the section.

func Span

func Span(text string) Element

Returns a new span element

func String

func String(text string) Element

returns a simple string content as an element This is useful for creating text nodes without any HTML tags.

func Style

func Style(css string) Element

returns a style tag with the given css code WITHOUT ESCAPING

func Stylesheet

func Stylesheet(url string) Element

returns a stylesheet link The url parameter specifies the URL of the stylesheet. The link tag is set to have a rel attribute of "stylesheet". It is used to link external CSS files to the HTML document.

func Switch

func Switch[T comparable](value T, items ...any) Element

func Table

func Table(children ...Element) Element

returns a table element If children are provided, they will be added as the content of the table.

func Td

func Td(children ...Element) Element

returns a table cell element If children are provided, they will be added as the content of the cell.

func Template

func Template(children ...Element) Element

returns an Alpine template element If children are provided, they will be added as the content of the template.

func Th

func Th(children ...Element) Element

returns a table header row element If children are provided, they will be added as the content of the header row.

func Title

func Title(text string) Element

Returns a new title element with the given text. This is typically used for the title of an HTML document.

func Tr

func Tr(children ...Element) Element

returns a table row element If children are provided, they will be added as the content of the row.

func Ul

func Ul(children ...Element) Element

returns a unordered list (ul) tag If children are provided, they will be added as the content of the unordered list.

func VideoIframe

func VideoIframe(title string, width int, height int, src string) Element

returns an iframe tag The title parameter sets the title attribute of the iframe. The width and height parameters specify the dimensions of the iframe. The src parameter specifies the source URL of the iframe. The iframe is set to allow autoplay, fullscreen, picture-in-picture, and clipboard-write. It also has a class of "w-full h-full" for styling. The data-ready attribute is set to "true" to indicate that the iframe is ready. The frameborder attribute is set to "0" to remove the border around the iframe.

type Field

type Field struct {
	DefaultElement
	Label Element
	Input Element
	Error Element
	Check Element
}

func Checkbox

func Checkbox(name, label, value string) *Field

func HiddenField

func HiddenField(name, label, value string) *Field

func NewField

func NewField(name, label, value, tipe string) *Field

func Radio

func Radio(name, label, value string) *Field

func Select

func Select(name, label, value string, options []Option, renderOption ...func(option Option, value string) Element) *Field

func TextField

func TextField(name, label, value string) *Field

func Textarea

func Textarea(name, label, value string) *Field

func (*Field) Checked

func (t *Field) Checked(value ...bool) *Field

Sets the checked attribute of the input element

func (*Field) Email

func (t *Field) Email(is_email ...bool) *Field

Sets the type of the input element to "email" if is_email is not specified or true Sets type to "text" if is_email is false

func (*Field) Password

func (t *Field) Password(is_password ...bool) *Field

Sets the type of the input element to "password" if is_password is not specified or true Sets type to "text" if is_password is false

func (*Field) Required

func (t *Field) Required(required ...bool) *Field

Sets the required and onblur attributes of the input element

type Option

type Option struct {
	Label string
	Value string
}

func OptionStrings

func OptionStrings[T ~string](options []T) []Option

type PictureSource

type PictureSource struct {
	Media string
	Src   string
}

type SvgCircle

type SvgCircle struct {
	DefaultElement
}

func Circle

func Circle(x, y, radius int) *SvgCircle

func (*SvgCircle) At

func (t *SvgCircle) At(x, y int) *SvgCircle

func (*SvgCircle) CenterX

func (t *SvgCircle) CenterX(x int) *SvgCircle

func (*SvgCircle) CenterY

func (t *SvgCircle) CenterY(y int) *SvgCircle

func (*SvgCircle) Fill

func (t *SvgCircle) Fill(color string) *SvgCircle

func (*SvgCircle) FillOpacity

func (t *SvgCircle) FillOpacity(opacity float64) *SvgCircle

func (*SvgCircle) Filter

func (t *SvgCircle) Filter(filter string) *SvgCircle

func (*SvgCircle) Opacity

func (t *SvgCircle) Opacity(opacity float64) *SvgCircle

func (*SvgCircle) Radius

func (t *SvgCircle) Radius(radius int) *SvgCircle

func (*SvgCircle) Stroke

func (t *SvgCircle) Stroke(color string) *SvgCircle

func (*SvgCircle) StrokeDasharray

func (t *SvgCircle) StrokeDasharray(dasharray string) *SvgCircle

func (*SvgCircle) StrokeLinecap

func (t *SvgCircle) StrokeLinecap(linecap string) *SvgCircle

func (*SvgCircle) StrokeLinejoin

func (t *SvgCircle) StrokeLinejoin(linejoin string) *SvgCircle

func (*SvgCircle) StrokeMiterlimit

func (t *SvgCircle) StrokeMiterlimit(miterlimit float64) *SvgCircle

func (*SvgCircle) StrokeOpacity

func (t *SvgCircle) StrokeOpacity(opacity float64) *SvgCircle

func (*SvgCircle) StrokeWidth

func (t *SvgCircle) StrokeWidth(width int) *SvgCircle

type SvgElement

type SvgElement struct {
	DefaultElement
}

func Svg

func Svg(children ...Element) *SvgElement

func (*SvgElement) D

func (s *SvgElement) D(d string) *SvgElement

func (*SvgElement) Height

func (s *SvgElement) Height(height int) *SvgElement

func (*SvgElement) Version

func (s *SvgElement) Version(version string) *SvgElement

func (*SvgElement) ViewBox

func (s *SvgElement) ViewBox(x, y, width, height int) *SvgElement

func (*SvgElement) Width

func (s *SvgElement) Width(width int) *SvgElement

func (*SvgElement) Xmlns

func (s *SvgElement) Xmlns(xmlns string) *SvgElement
func (s *SvgElement) XmlnsXlink(xmlnsXlink string) *SvgElement

type SvgGroup

type SvgGroup struct {
	DefaultElement
}

func Group

func Group(children ...Element) *SvgGroup

type SvgImage

type SvgImage struct {
	DefaultElement
}

func Image

func Image(x, y, width, height int, href string) *SvgImage

func (*SvgImage) At

func (i *SvgImage) At(x, y int) *SvgImage

func (*SvgImage) Height

func (i *SvgImage) Height(height int) *SvgImage

func (*SvgImage) Href

func (i *SvgImage) Href(href string) *SvgImage

func (*SvgImage) Size

func (i *SvgImage) Size(width, height int) *SvgImage

func (*SvgImage) Width

func (i *SvgImage) Width(width int) *SvgImage

func (*SvgImage) X

func (i *SvgImage) X(x int) *SvgImage

func (*SvgImage) Y

func (i *SvgImage) Y(y int) *SvgImage

type SvgLine

type SvgLine struct {
	DefaultElement
}

func Line

func Line(x1, y1, x2, y2 int) *SvgLine

func (*SvgLine) Fill

func (t *SvgLine) Fill(color string) *SvgLine

func (*SvgLine) FillOpacity

func (t *SvgLine) FillOpacity(opacity float64) *SvgLine

func (*SvgLine) From

func (t *SvgLine) From(x, y int) *SvgLine

func (*SvgLine) Opacity

func (t *SvgLine) Opacity(opacity float64) *SvgLine

func (*SvgLine) Stroke

func (t *SvgLine) Stroke(color string) *SvgLine

func (*SvgLine) StrokeDasharray

func (t *SvgLine) StrokeDasharray(dasharray string) *SvgLine

func (*SvgLine) StrokeDashoffset

func (t *SvgLine) StrokeDashoffset(offset float64) *SvgLine

func (*SvgLine) StrokeLinecap

func (t *SvgLine) StrokeLinecap(linecap string) *SvgLine

func (*SvgLine) StrokeLinejoin

func (t *SvgLine) StrokeLinejoin(linejoin string) *SvgLine

func (*SvgLine) StrokeMiterlimit

func (t *SvgLine) StrokeMiterlimit(miterlimit float64) *SvgLine

func (*SvgLine) StrokeWidth

func (t *SvgLine) StrokeWidth(width float64) *SvgLine

func (*SvgLine) To

func (t *SvgLine) To(x, y int) *SvgLine

type SvgPath

type SvgPath struct {
	DefaultElement
}

func Path

func Path() *SvgPath

func (*SvgPath) ClipPath

func (p *SvgPath) ClipPath(clipPath string) *SvgPath

func (*SvgPath) D

func (p *SvgPath) D(d string) *SvgPath

func (*SvgPath) Fill

func (p *SvgPath) Fill(fill string) *SvgPath

func (*SvgPath) Filter

func (p *SvgPath) Filter(filter string) *SvgPath

func (*SvgPath) Opacity

func (p *SvgPath) Opacity(opacity float64) *SvgPath

func (*SvgPath) PathLength

func (p *SvgPath) PathLength(length float64) *SvgPath

func (*SvgPath) Stroke

func (p *SvgPath) Stroke(stroke string) *SvgPath

func (*SvgPath) StrokeDasharray

func (p *SvgPath) StrokeDasharray(dasharray string) *SvgPath

func (*SvgPath) StrokeDashoffset

func (p *SvgPath) StrokeDashoffset(offset float64) *SvgPath

func (*SvgPath) StrokeLinecap

func (p *SvgPath) StrokeLinecap(linecap string) *SvgPath

func (*SvgPath) StrokeLinejoin

func (p *SvgPath) StrokeLinejoin(linejoin string) *SvgPath

func (*SvgPath) StrokeMiterlimit

func (p *SvgPath) StrokeMiterlimit(miterlimit float64) *SvgPath

func (*SvgPath) StrokeWidth

func (p *SvgPath) StrokeWidth(width float64) *SvgPath

func (*SvgPath) Transform

func (p *SvgPath) Transform(transform string) *SvgPath

type SvgRect

type SvgRect struct {
	DefaultElement
}

func Rect

func Rect(x, y, width, height int) *SvgRect

func (*SvgRect) ClipPath

func (t *SvgRect) ClipPath(clipPath string) *SvgRect

func (*SvgRect) Fill

func (t *SvgRect) Fill(color string) *SvgRect

func (*SvgRect) FillOpacity

func (t *SvgRect) FillOpacity(opacity float64) *SvgRect

func (*SvgRect) Filter

func (t *SvgRect) Filter(filter string) *SvgRect

func (*SvgRect) Height

func (t *SvgRect) Height(height int) *SvgRect

func (*SvgRect) Opacity

func (t *SvgRect) Opacity(opacity float64) *SvgRect

func (*SvgRect) RX

func (t *SvgRect) RX(rx int) *SvgRect

func (*SvgRect) RY

func (t *SvgRect) RY(ry int) *SvgRect

func (*SvgRect) Stroke

func (t *SvgRect) Stroke(color string) *SvgRect

func (*SvgRect) StrokeDasharray

func (t *SvgRect) StrokeDasharray(dasharray string) *SvgRect

func (*SvgRect) StrokeLinecap

func (t *SvgRect) StrokeLinecap(linecap string) *SvgRect

func (*SvgRect) StrokeLinejoin

func (t *SvgRect) StrokeLinejoin(linejoin string) *SvgRect

func (*SvgRect) StrokeMiterlimit

func (t *SvgRect) StrokeMiterlimit(miterlimit float64) *SvgRect

func (*SvgRect) StrokeOpacity

func (t *SvgRect) StrokeOpacity(opacity float64) *SvgRect

func (*SvgRect) StrokeWidth

func (t *SvgRect) StrokeWidth(width int) *SvgRect

func (*SvgRect) Transform

func (t *SvgRect) Transform(transform string) *SvgRect

func (*SvgRect) Width

func (t *SvgRect) Width(width int) *SvgRect

func (*SvgRect) X

func (t *SvgRect) X(x int) *SvgRect

func (*SvgRect) Y

func (t *SvgRect) Y(y int) *SvgRect

type SvgText

type SvgText struct {
	DefaultElement
}

func Text

func Text(x, y int, text string) *SvgText

func (*SvgText) AlignmentBaseline

func (t *SvgText) AlignmentBaseline(baseline string) *SvgText

func (*SvgText) DominantBaseline

func (t *SvgText) DominantBaseline(baseline string) *SvgText

func (*SvgText) Dx

func (t *SvgText) Dx(dx float64) *SvgText

func (*SvgText) Dy

func (t *SvgText) Dy(dy float64) *SvgText

func (*SvgText) Fill

func (t *SvgText) Fill(color string) *SvgText

func (*SvgText) FontFamily

func (t *SvgText) FontFamily(fontFamily string) *SvgText

func (*SvgText) FontSize

func (t *SvgText) FontSize(size int) *SvgText

func (*SvgText) FontSizeAdjust

func (t *SvgText) FontSizeAdjust(sizeAdjust string) *SvgText

func (*SvgText) FontStyle

func (t *SvgText) FontStyle(style string) *SvgText

func (*SvgText) FontWeight

func (t *SvgText) FontWeight(weight string) *SvgText

func (*SvgText) LengthAdjust

func (t *SvgText) LengthAdjust(lengthAdjust string) *SvgText

func (*SvgText) LetterSpacing

func (t *SvgText) LetterSpacing(spacing float64) *SvgText

func (*SvgText) Rotate

func (t *SvgText) Rotate(angle float64) *SvgText

func (*SvgText) SetText

func (t *SvgText) SetText(text string) *SvgText

func (*SvgText) Stroke

func (t *SvgText) Stroke(color string) *SvgText

func (*SvgText) StrokeDasharray

func (t *SvgText) StrokeDasharray(dasharray string) *SvgText

func (*SvgText) StrokeDashoffset

func (t *SvgText) StrokeDashoffset(offset float64) *SvgText

func (*SvgText) StrokeLinecap

func (t *SvgText) StrokeLinecap(linecap string) *SvgText

func (*SvgText) StrokeLinejoin

func (t *SvgText) StrokeLinejoin(linejoin string) *SvgText

func (*SvgText) StrokeMiterlimit

func (t *SvgText) StrokeMiterlimit(miterlimit float64) *SvgText

func (*SvgText) StrokeWidth

func (t *SvgText) StrokeWidth(width float64) *SvgText

func (*SvgText) TextAnchor

func (t *SvgText) TextAnchor(anchor string) *SvgText

func (*SvgText) TextDecoration

func (t *SvgText) TextDecoration(decoration string) *SvgText

func (*SvgText) TextLength

func (t *SvgText) TextLength(length float64) *SvgText

func (*SvgText) TextPath

func (t *SvgText) TextPath(path string) *SvgText

func (*SvgText) Transform

func (t *SvgText) Transform(transform string) *SvgText

func (*SvgText) WordSpacing

func (t *SvgText) WordSpacing(spacing float64) *SvgText

func (*SvgText) WritingMode

func (t *SvgText) WritingMode(mode string) *SvgText

func (*SvgText) X

func (t *SvgText) X(x int) *SvgText

func (*SvgText) Y

func (t *SvgText) Y(y int) *SvgText

Jump to